:
BC_PRIVATE=	#INSTALL (default BC_PRIVATE path)

# ------------------------------------------------------------------
#       AutoSelecting a user-defined Repository
#
#  If the env variable BC_REPOSITORY is set to an absolute path,
#  that path is set into BC_PRIVATE, in effect, selecting a specific
#  set of repository directories (BriefCase, Stage and projRCS) for
#  this BC.profile session.
# 
#  To switch to another repository, set BC_REPOSITORY to the path
#  to its set of repository directories and source 
#
#    $BC_REPOSITORY/BC.profile
#
#  again.
#
if [ "$BC_REPOSITORY" != "" ]
then 
    BC_RepoPath=`echo $BC_REPOSITORY | awk 'BEGIN{
            StdErr = "cat 1>&2"
        }
        $1 ~ /^\// {
	    print $1
	    exit
	}
        {   print "Error - BC_REPOSITORY not abs. path" | StdErr
	    print ""
	    exit
        } '`
    if [ "$BC_RepoPath" != "" -a -d "$BC_RepoPath" ]
    then
	if [ -d $BC_RepoPath/BriefCase ]
	then if [ -d $BC_RepoPath/Stage ]
	    then BC_PRIVATE=$BC_RepoPath; export BC_PRIVATE
	    else
                echo "Error - $BC_RepoPath is not a /BriefCase Repository"
	    fi
	else
            echo "Error - $BC_RepoPath is not a /BriefCase Repository"
	fi
    else
	echo "Error - $BC_RepoPath is not a directory"
    fi
fi
# ------------------------------------------------------------------
#
#  BCclean - Cleans all references to /BriefCase from environment vars
#            in preparation for restablishment of this (new) instance 
#            of BriefCase.  Typical usage is:  eval `BCclean`
#
BCclean(){  
	env | grep BriefCase | awk '
	{	
		tc = split($0, t, "=")
		printf "%s=", t[1]
		tca = split(t[2], a, ":")
		sep = ""
		for (n = 1; n <= tca; n++){
			arg = a[n]
			if ( arg ~ /\/BriefCase/ )
				continue
			printf "%s%s", sep, arg
			sep = ":"
		}
		printf";\n"
	}'
}
#----------------------------------------------------------
#  WARNING: This file is "sourced", DO NOT invoke a shell here!
#----------------------------------------------------------
echo "
Welcome to /BriefCase!

    Connecting to /BriefCase Server ... 
"
#  If the /Stage/home/$LOGNAME directory is not writable, /BriefCase
#  cannot migrate files between the client and server and many commands
#  will fail.
#
ERRM=`touch $BC_PRIVATE/Stage/home/$LOGNAME.$$ 2>&1`
RC=$?
rm -f $BC_PRIVATE/Stage/home/$LOGNAME.$$
if [ $RC -gt 0 ]
then
    echo "
ERROR: /BriefCase connect failed: Staging area (/Stage/home/$LOGNAME)
       is not writable by host: `uname -n`
       and/or user $LOGNAME.

  Notify the SysAdmin for this client host and/or the /BriefCase(tm)
  Administrator of this error ASAP!
  
  DO NOT attempt to use /BriefCase commands until this problem is resolved!

"
else
  eval `BCclean`
  # /BriefCase Installation Profile Info
  #
  BC_PATH=$BC_PRIVATE/BriefCase   #INSTALL
  BC_REV=3.4b;			#INSTALL
  MANPATH=$MANPATH:$BC_PATH/man
  export BC_PRIVATE BC_PATH BC_REV MANPATH
  
  #  If a /BriefCase/nawk link points to an old-style awk cmd, the "-v variable"
  #  args won;t work!  Assuming a new-style awk exists and is found by
  #  the "BCwhence nawk", the /BriefCase/nawk link should be removed.
  #
  if [ -x $BC_PATH/nawk ]
  then
  	NAWK=`$BC_PATH/BCwhence nawk | cut -d' ' -f1 `
  	if [ "x$NAWK" != xno ]
  	then echo "
WARNING: /BriefCase/nawk link hides $NAWK.
   Inform /BriefCase(tm) Administrator ASAP!
  "
  	fi
  	unset NAWK
  fi
  
  # Look for Host-specific (server/client) profile info
  O_PATH=$PATH  # hold original path for insertion of BC_CPU/BC_OS settings
  PATH=$BC_PATH:$PATH
  export PATH
  PROFILE=$BC_PRIVATE/BriefCase/profiles/`uname -n`
  TF=/tmp/tf$$
  
  if [ -x $PROFILE ]
  then
  	# Install host-specific profile to define BC_CPU and BC_OS env. vars
  	/bin/sh $PROFILE > $TF
  else
  	# Otherwise, use default which builds BC_CPU/BC_OS env. vars
  	# from uname output.
  	/bin/sh $BC_PRIVATE/BriefCase/profiles/default > $TF
  	echo BC.profile: default profile used
  fi
  
  . $TF
  /bin/rm $TF
  
  # Determine server-os and BC_CPU type
  if [ "$BCSERVER" = `uname -n` ]
  then BC_SERVER_OS=$BC_OS
  	 BC_SERVER_CPU=$BC_CPU
  else BC_SERVER_OS=`BCrsh $BCSERVER "uname -s" |
      awk '{ if ($1 ~ /CYGWIN/) {
                 print "cygwin32"
             } else {
  		   	   print $1
  		   }
             exit
           }'`
       BC_SERVER_CPU=`BCrsh $BCSERVER "uname -m" `
  fi
  export BC_SERVER_OS BC_SERVER_CPU
  
  # NOTE that BC_CPU and BC_OS are set in the host-specific setup scripts,
  # so PATH cannot be completely set up prior to this...
  #
  PATH=$BC_PATH:$BC_PATH/$BC_CPU/$BC_OS/bin:$O_PATH
  
  echo "
   Using /BriefCase(tm) Rev $BC_REV installed at:
      $BC_PATH
   (c)1992,2002 Applied Computer Sciences, inc. and distributed
     under the terms of the GNU GPL (ver. 2, June 1991)
  
       Client: `uname -n`  CPU: $BC_CPU  OS: $BC_OS
       BCServer: $BCSERVER  CPU: $BC_SERVER_CPU OS:  $BC_SERVER_OS
  "
if [ "$BC_PRIVATE" != "" ]
then echo "       Selected Repository: $BC_PRIVATE
  "
fi
  
  
  # --------------------------------------------------------------------
  #
  #    BC_DTP_PROMO feature is enabled globally
  #    by setting env. var. BC_DTP_PROMO to "yes": 
  #    
  BC_DTP_PROMO=yes   #INSTALL - yes enables Dev/Test/Prod promotion commands
  export BC_DTP_PROMO
  #
  #
  #  Dev/Test/Prod runtime promotion setup used by QA_pull and dtp_promote
  #  commands.
  #    
  #  Define DTP Directory heads
  #
  BC_DTP_DEV=DEVpkg    #INSTALL  Development Runtime Tree Head
  BC_DTP_TEST=TSTpkg    #INSTALL  QA/Test Runtime Tree Head
  BC_DTP_PROD=PRDpkg    #INSTALL  Production Runtime Tree Head
  
  export BC_DTP_DEV BC_DTP_TEST BC_DTP_PROD 
  
  if [ "$BC_DTP_PROMO" = yes ]
  then
    #
    #  This is a good place to test if current user if in BCadmin group
    #  or possibly in a special "Project Admin" group for this project.
    #
    #  TBD - dmk
    #
    echo Runtime Promotion features enabled
    if [ "$BC_RUNTIME" != "" ]
    then
  	  #  Set top-level Dev/Test/Prod runtime path
  	  BC_PKGPATH=${BC_RUNTIME}pkg
  	  export BC_PKGPATH
    
  	  echo "Runtime Path set to ~/$BC_PKGPATH"
    else 
  	  echo "
WARNING: env. var. BC_RUNTIME not set;  Runtime Promotion cmds disabled!
    "
    fi
  else
    : # Runtime Promotion features not configured.
  fi
fi  # 
